@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -32,6 +32,7 @@ import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 
 
 /**
@@ -139,7 +140,7 @@ public class MailNotifyPushUdpSocketListener implements Runnable {
 
         String packetDataString = new String(datagramPacket.getData());
         // User name at position 3, see above
-        packetDataString = packetDataString.split("\0")[3];
+        packetDataString = Strings.splitBy(packetDataString, '\0', false)[3];
 
         String delimiter = imapLoginDelimiter;
         if (null != delimiter) {
